@@ -191,7 +191,7 @@ cvrisk.mboostLSS <- function(object, folds = cv(model.weights(object)),
     
     OOBweights <- matrix(rep(weights, ncol(folds)), ncol = ncol(folds))
     OOBweights[folds > 0] <- 0
-    if (all.equal(papply, mclapply) == TRUE) {
+    if (identical(papply, mclapply)) {
         oobrisk <- papply(1:ncol(folds),
                           function(i) dummyfct(i, weights = folds[, i],
                                                oobweights = OOBweights[, i]),
