@@ -123,16 +123,16 @@ mboostLSS_fit <- function(formula, data = list(), families = GaussianLSS(),
     trace <- control$trace
     control$trace <- FALSE
 
-    ## generate adequate model weights 
+    ## generate adequate model weights
     w <- weights
-    
+
     if (is.null(weights)){
       if (!is.list(response)) {
         weights <- rep.int(1, NROW(response))
         # expand weights if the response is a matrix (functional response)
         if(funchar == "FDboost" && !is.null(dim(response)) && !any(dim(response) == 1))
           weights <- rep.int(weights, ncol(response))
-        
+
       } else {
         weights <- rep.int(1, NROW(response[[1]]))
         # expand weights if the response is a matrix (functional response)
@@ -140,19 +140,19 @@ mboostLSS_fit <- function(formula, data = list(), families = GaussianLSS(),
           weights <- rep.int(weights, ncol(response[[1]]))
       }
     }
-    
+
     weights <- rescale_weights(weights)
-    
-    ## set up timeformula for FDboost 
+
+    ## set up timeformula for FDboost
     if (funchar == "FDboost"){
-      
-      # get timeformula from dots 
+
+      # get timeformula from dots
       dots <- list(...)
       timeformula <- dots$timeformula
       dots$timeformula <- NULL
-      
+
       # deal with argument timeformula in case of FDboost()
-      # timeformula is named list with names according to 
+      # timeformula is named list with names according to
       # distribution parameters of families
       timeformula <- check_timeformula(timeformula, families)
     }
@@ -166,14 +166,14 @@ mboostLSS_fit <- function(formula, data = list(), families = GaussianLSS(),
     names(offset) <- names(families)
     for (j in mods){
         if (!is.list(response)) {
-          response <- check_y_family(response, families[[j]], 
+          response <- check_y_family(response, families[[j]],
                                      allow_matrix = (funchar == "FDboost"))
-          offset[[j]] <- families[[j]]@offset(y = if(funchar != "FDboost") response else c(response), 
+          offset[[j]] <- families[[j]]@offset(y = if(funchar != "FDboost") response else c(response),
                                               w = weights)
         } else {
-          response[[j]] <- check_y_family(response[[j]], families[[j]], 
+          response[[j]] <- check_y_family(response[[j]], families[[j]],
                                           allow_matrix = (funchar == "FDboost"))
-          offset[[j]] <- families[[j]]@offset(y = if(funchar != "FDboost") response[[j]] else c(response[[j]]), 
+          offset[[j]] <- families[[j]]@offset(y = if(funchar != "FDboost") response[[j]] else c(response[[j]]),
                                               w = weights)
         }
         for (k in mods){
@@ -187,7 +187,7 @@ mboostLSS_fit <- function(formula, data = list(), families = GaussianLSS(),
     for (j in mods){
         ## update value of nuisance parameters in families
         for (k in mods[-j]){
-            if (!is.null(fit[[k]])) ## use fitted.mboost() as fitted.FDboost() returns a matrix  
+            if (!is.null(fit[[k]])) ## use fitted.mboost() as fitted.FDboost() returns a matrix
                 assign(names(fit)[k], families[[k]]@response(fitted.mboost(fit[[k]])),
                        environment(families[[j]]@ngradient))
         }
@@ -203,9 +203,9 @@ mboostLSS_fit <- function(formula, data = list(), families = GaussianLSS(),
           fit[[j]] <- do.call(fun, c(list(formula[[names(families)[[j]]]],
                                         timeformula = timeformula[[names(families)[[j]]]],
                                         data = data, family = families[[j]],
-                                        control = control, weights = w, 
+                                        control = control, weights = w,
                                         # always use scalar offset, as offsets are treated within the Family
-                                        offset = "scalar"), 
+                                        offset = "scalar"),
                                      dots))
         }
 
@@ -255,9 +255,9 @@ mboostLSS_fit <- function(formula, data = list(), families = GaussianLSS(),
                 for(b  in 1:length(fit)){
                     st <- mstop(fit[[b]])
                     mstop(fit[[b]]) = st + 1
-                    risks[b] <- tail(risk(fit[[b]]), 1)
+                    #risks[b] <- tail(risk(fit[[b]]), 1)
                     #evalq({riskfct(y, fit, weights)}, envir = ENV[[b]])
-                    #risks[b] <- ENV[[b]][["riskfct"]](ENV[[b]][["y"]], ENV[[b]][["fit"]], ENV[[b]][["weights"]])
+                    risks[b] <- ENV[[b]][["riskfct"]](ENV[[b]][["y"]], ENV[[b]][["fit"]], ENV[[b]][["weights"]])
                     fit[[b]][st]
 
                     ## fit[[b]][st] is not enough to reduce the model back to beginning, so
@@ -481,7 +481,7 @@ mboostLSS_fit <- function(formula, data = list(), families = GaussianLSS(),
         ## re-use user specified offset only
         ## (since it depends on weights otherwise)
         ## this is achieved via a re-evaluation of the families argument
-        
+
         if(funchar != "FDboost"){
           mboostLSS_fit(formula = formula, data = data,
                         families = eval(call[["families"]]), weights = weights,
@@ -493,10 +493,10 @@ mboostLSS_fit <- function(formula, data = list(), families = GaussianLSS(),
                         families = eval(call[["families"]]), weights = weights,
                         control = control, fun = fun, funchar = funchar,
                         call = call, oobweights = oobweights,
-                        method = method, 
+                        method = method,
                         timeformula = timeformula[[names(families)[[j]]]])
         }
-        
+
     }
     attr(fit, "control") <- control
     attr(fit, "call") <- call
